@@ -27,19 +27,20 @@
   * <https://www.gnu.org/licenses/>.
  */
 import { ActionContext } from 'vuex';
-import { Locale } from '../locale/locale.models';
 import { RootState } from '../../root.models';
 
-export type Title = Record<Locale, string>;
-
-export type Description = Record<Locale, string>;
+export type LocalizedString = Record<string, string>;
 
 export type LinkTarget = 'newwindow' | 'samewindow' | 'embedded' | 'function';
 
 export type LinkTargetOrDefault = 'newwindow' | 'samewindow' | 'embedded' | 'function' | 'useportaldefault';
 
+export interface PortalImageDataBlob {
+  data: string,
+}
+
 export interface Link {
-  locale: Locale,
+  locale: string,
   link: string,
 }
 
@@ -47,7 +48,7 @@ export interface Tile {
   id: string,
   layoutId: string,
   dn: string,
-  title: Title,
+  title: LocalizedString,
   isFolder: boolean,
 }
 
@@ -57,8 +58,10 @@ export interface BaseTile extends Tile {
   anonymous: boolean,
   selectedGroups: string[],
   backgroundColor: string | null,
-  description: Description,
+  description: LocalizedString,
+  keywords: LocalizedString,
   linkTarget: LinkTarget,
+  target: string | null,
   originalLinkTarget: LinkTargetOrDefault,
   links: Link[],
   pathToLogo: string,
@@ -74,14 +77,12 @@ export type TileOrFolder = BaseTile | FolderTile;
 export interface Category {
   id: string,
   layoutId: string,
-  title: Record<Locale, string>,
+  title: LocalizedString,
   dn: string,
   virtual: boolean,
   tiles: TileOrFolder[],
 }
 
-export type LocalizedString = Record<string, string>;
-
 export type PortalContent = [string, string[]][];
 
 export interface PortalEntry {
@@ -91,8 +92,10 @@ export interface PortalEntry {
   allowedGroups: string[],
   anonymous: boolean,
   backgroundColor: string | null,
-  description: Description,
+  description: LocalizedString,
+  keywords: LocalizedString,
   linkTarget: LinkTargetOrDefault,
+  target: string | null,
   links: Link[],
   logo_name: string | null,
   name: LocalizedString,
@@ -158,10 +161,6 @@ export interface PortalDataState {
   errorContentType: number | null;
 }
 
-export interface PortalImageDataBlob {
-  data: string,
-}
-
 export type Position = {
   categoryIdx: null | number;
   folderIdx: null | number;
